import * as React from 'react';
interface FadeAnimationHandle {
  /**
   * @param {number} fadeTo - the fade value to fade onto
   * @description triggers fade animation from the endOpacity of initial config
   * to the param provided
   * @returns {void}
   */
  triggerAnimation: (fadeTo: number) => void;
}

export interface FadeAnimationConfig {
  duration?: number;
  startOpacity?: number;
  endOpacity?: number;
}

/**
 * @interface FadeProps
 * @param {React.ReactNode} children
 * @param {Function} onFadeStart - callback to track when the animation starts
 * @param {Function} onFadeEnd - callback to track when the animation ends
 * @param {FadeAnimationConfig} config - to control "duration" of animation, "start" and "end" opacity of child component
 */
interface FadeProps {
  children: React.ReactNode;
  onFadeStart?: Function;
  onFadeEnd?: Animated.EndCallback;
  config?: FadeAnimationConfig;
  ref?: React.RefObject<FadeAnimationHandle>;
}

export default function Fade(props: FadeProps): JSX.Element;
